==> simgrid_3.9~rc1.orig.tar.gz: SimGrid-3.9/doc/html/group__XBT__str.js <==
var group__XBT__str =
[
    [ "xbt_str_rtrim", "group__XBT__str.html#ga9d7c43274b5a6339adfc724e2efd0ead", null ],
    [ "xbt_str_ltrim", "group__XBT__str.html#gaeb745f202229799d900aa3a20953186f", null ],
    [ "xbt_str_trim", "group__XBT__str.html#ga5259c70a74df4d63f39e68cc5fe8f1b3", null ],
    [ "xbt_str_split", "group__XBT__str.html#ga91672ded3b13340f1dfa6fb5ce64fb42", null ],
    [ "xbt_str_split_quoted", "group__XBT__str.html#gaa6839f81f1789acf3865eeade8c23c77", null ],
    [ "xbt_str_split_quoted_in_place", "group__XBT__str.html#ga2454f448cda4a1ba94409196a2f31d78", null ],
    [ "xbt_str_split_str", "group__XBT__str.html#ga84523a36aef41594015c8c2a22256385", null ],
    [ "xbt_str_join", "group__XBT__str.html#ga1271575a77363ce72fbdf65298a49622", null ],
    [ "xbt_str_join_array", "group__XBT__str.html#ga17585fd9f6432df9f84db21059486900", null ],
    [ "xbt_str_subst", "group__XBT__str.html#ga2aaaa9b7cdc3e30d0a2b85c7561ad0e6", null ],
    [ "xbt_str_varsubst", "group__XBT__str.html#ga42a82b549ada759cfc7ec4e0999dde1e", null ],
    [ "xbt_str_strip_spaces", "group__XBT__str.html#ga5b8c3f04c5bd47a54c6700c634c48d40", null ],
    [ "xbt_str_diff", "group__XBT__str.html#gadfd8938aaade2e991b8b51bed5aea886", null ],
    [ "xbt_str_from_file", "group__XBT__str.html#ga3d0726833fdc157351600358cc67097c", null ],
    [ "xbt_str_hash_ext", "group__XBT__str.html#ga10c19e31b7f944a5f426a7d436a44e6d", null ],
    [ "xbt_str_hash", "group__XBT__str.html#ga7b484f038534879efb07619091341977", null ]
];

==> simgrid_3.10.orig.tar.gz: SimGrid-3.10/doc/html/group__XBT__str.js <==
var group__XBT__str =
[
    [ "asprintf", "group__XBT__str.html#ga873b085fd80ad9b0cee0f841f48eb1d1", null ],
    [ "vasprintf", "group__XBT__str.html#gaf354d1d051622132c673dde7cfd63b79", null ],
    [ "bvprintf", "group__XBT__str.html#ga2faec67938497d455b6ab3ccb69d7fb3", null ],
    [ "bprintf", "group__XBT__str.html#ga6f0a0c16ffed231430899dabdb426ac6", null ],
    [ "xbt_getline", "group__XBT__str.html#ga7e85b04b6111d11c26329b4b6d2bfb89", null ],
    [ "xbt_str_rtrim", "group__XBT__str.html#ga9d7c43274b5a6339adfc724e2efd0ead", null ],
    [ "xbt_str_ltrim", "group__XBT__str.html#gaeb745f202229799d900aa3a20953186f", null ],
    [ "xbt_str_trim", "group__XBT__str.html#ga5259c70a74df4d63f39e68cc5fe8f1b3", null ],
    [ "xbt_str_split", "group__XBT__str.html#ga91672ded3b13340f1dfa6fb5ce64fb42", null ],
    [ "xbt_str_split_quoted", "group__XBT__str.html#gaa6839f81f1789acf3865eeade8c23c77", null ],
    [ "xbt_str_split_quoted_in_place", "group__XBT__str.html#ga2454f448cda4a1ba94409196a2f31d78", null ],
    [ "xbt_str_split_str", "group__XBT__str.html#ga84523a36aef41594015c8c2a22256385", null ],
    [ "xbt_str_join", "group__XBT__str.html#ga1271575a77363ce72fbdf65298a49622", null ],
    [ "xbt_str_join_array", "group__XBT__str.html#ga17585fd9f6432df9f84db21059486900", null ],
    [ "xbt_str_subst", "group__XBT__str.html#ga2aaaa9b7cdc3e30d0a2b85c7561ad0e6", null ],
    [ "xbt_str_varsubst", "group__XBT__str.html#ga42a82b549ada759cfc7ec4e0999dde1e", null ],
    [ "xbt_str_strip_spaces", "group__XBT__str.html#ga5b8c3f04c5bd47a54c6700c634c48d40", null ],
    [ "xbt_str_diff", "group__XBT__str.html#gadfd8938aaade2e991b8b51bed5aea886", null ],
    [ "xbt_str_from_file", "group__XBT__str.html#ga3d0726833fdc157351600358cc67097c", null ],
    [ "xbt_str_hash_ext", "group__XBT__str.html#ga10c19e31b7f944a5f426a7d436a44e6d", null ],
    [ "xbt_str_hash", "group__XBT__str.html#ga7b484f038534879efb07619091341977", null ]
];
